# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ViewColumnFilterInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter_group_label': 'int',
        'filter_operation': 'str',
        'filter_value': 'str'
    }

    attribute_map = {
        'filter_group_label': 'filterGroupLabel',
        'filter_operation': 'filterOperation',
        'filter_value': 'filterValue'
    }

    def __init__(self, filter_group_label=None, filter_operation=None, filter_value=None):
        """
        ViewColumnFilterInputV1 - a model defined in Swagger
        """

        self._filter_group_label = None
        self._filter_operation = None
        self._filter_value = None

        if filter_group_label is not None:
          self.filter_group_label = filter_group_label
        if filter_operation is not None:
          self.filter_operation = filter_operation
        if filter_value is not None:
          self.filter_value = filter_value

    @property
    def filter_group_label(self):
        """
        Gets the filter_group_label of this ViewColumnFilterInputV1.
        The integer label for referencing this filter in the Hierarchy's filter grouping. If the Hierarchy has a filter grouping defined, this value is required

        :return: The filter_group_label of this ViewColumnFilterInputV1.
        :rtype: int
        """
        return self._filter_group_label

    @filter_group_label.setter
    def filter_group_label(self, filter_group_label):
        """
        Sets the filter_group_label of this ViewColumnFilterInputV1.
        The integer label for referencing this filter in the Hierarchy's filter grouping. If the Hierarchy has a filter grouping defined, this value is required

        :param filter_group_label: The filter_group_label of this ViewColumnFilterInputV1.
        :type: int
        """

        self._filter_group_label = filter_group_label

    @property
    def filter_operation(self):
        """
        Gets the filter_operation of this ViewColumnFilterInputV1.
        The filter operation to be applied to this column. This operation determines how the filterValue is applied to the column data. If the filterOperation is `IS_NULL` or `IS_NOT_NULL`, the filterValue must not be provided.

        :return: The filter_operation of this ViewColumnFilterInputV1.
        :rtype: str
        """
        return self._filter_operation

    @filter_operation.setter
    def filter_operation(self, filter_operation):
        """
        Sets the filter_operation of this ViewColumnFilterInputV1.
        The filter operation to be applied to this column. This operation determines how the filterValue is applied to the column data. If the filterOperation is `IS_NULL` or `IS_NOT_NULL`, the filterValue must not be provided.

        :param filter_operation: The filter_operation of this ViewColumnFilterInputV1.
        :type: str
        """
        if filter_operation is None:
            raise ValueError("Invalid value for `filter_operation`, must not be `None`")

        self._filter_operation = filter_operation

    @property
    def filter_value(self):
        """
        Gets the filter_value of this ViewColumnFilterInputV1.
        The filter value for this column. If not provided, the filterOperation must be `IS_NULL` or `IS_NOT_NULL`.

        :return: The filter_value of this ViewColumnFilterInputV1.
        :rtype: str
        """
        return self._filter_value

    @filter_value.setter
    def filter_value(self, filter_value):
        """
        Sets the filter_value of this ViewColumnFilterInputV1.
        The filter value for this column. If not provided, the filterOperation must be `IS_NULL` or `IS_NOT_NULL`.

        :param filter_value: The filter_value of this ViewColumnFilterInputV1.
        :type: str
        """

        self._filter_value = filter_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ViewColumnFilterInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class EmailerConfigurationOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _max_number_of_attachments: int
    _max_attachments_size_in_mb: float
    _allowed_attachment_types: List[str]


    def __init__(
        self,
        max_number_of_attachments: Optional[int] = None,
        max_attachments_size_in_mb: Optional[float] = None,
        allowed_attachment_types: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def max_number_of_attachments(self) -> int: ...

    @max_number_of_attachments.setter
    def max_number_of_attachments(self, max_number_of_attachments: int) -> None: ...

    @property
    def max_attachments_size_in_mb(self) -> float: ...

    @max_attachments_size_in_mb.setter
    def max_attachments_size_in_mb(self, max_attachments_size_in_mb: float) -> None: ...

    @property
    def allowed_attachment_types(self) -> List[str]: ...

    @allowed_attachment_types.setter
    def allowed_attachment_types(self, allowed_attachment_types: List[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _absolute_threshold: Optional[float]
    _applied_filters: Optional[List[BoardFilterInputV1]]
    _baseline_end: str
    _baseline_start: str
    _current_end: str
    _current_start: str
    _limit: Optional[int]
    _metric: Optional[str]
    _percent_threshold: Optional[float]
    _tile_ids: Optional[List[str]]


    def __init__(
        self,
        absolute_threshold: Optional[float] = None,
        applied_filters: Optional[List[BoardFilterInputV1]] = None,
        baseline_end: Optional[str] = None,
        baseline_start: Optional[str] = None,
        current_end: Optional[str] = None,
        current_start: Optional[str] = None,
        limit: Optional[int] = None,
        metric: Optional[str] = None,
        percent_threshold: Optional[float] = None,
        tile_ids: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def absolute_threshold(self) -> Optional[float]: ...

    @absolute_threshold.setter
    def absolute_threshold(self, absolute_threshold: Optional[float]) -> None: ...

    @property
    def applied_filters(self) -> Optional[List[BoardFilterInputV1]]: ...

    @applied_filters.setter
    def applied_filters(self, applied_filters: Optional[List[BoardFilterInputV1]]) -> None: ...

    @property
    def baseline_end(self) -> str: ...

    @baseline_end.setter
    def baseline_end(self, baseline_end: str) -> None: ...

    @property
    def baseline_start(self) -> str: ...

    @baseline_start.setter
    def baseline_start(self, baseline_start: str) -> None: ...

    @property
    def current_end(self) -> str: ...

    @current_end.setter
    def current_end(self, current_end: str) -> None: ...

    @property
    def current_start(self) -> str: ...

    @current_start.setter
    def current_start(self, current_start: str) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def metric(self) -> Optional[str]: ...

    @metric.setter
    def metric(self, metric: Optional[str]) -> None: ...

    @property
    def percent_threshold(self) -> Optional[float]: ...

    @percent_threshold.setter
    def percent_threshold(self, percent_threshold: Optional[float]) -> None: ...

    @property
    def tile_ids(self) -> Optional[List[str]]: ...

    @tile_ids.setter
    def tile_ids(self, tile_ids: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnDefinitionBulkEditInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_id': 'str',
        'column_name': 'str',
        'column_rules': 'list[ColumnRuleInputV1]',
        'column_type': 'str',
        'column_uom': 'str',
        'description': 'str',
        'display_property': 'str',
        'is_generated': 'bool',
        'is_hidden': 'bool',
        'is_indexed': 'bool',
        'sort_ascending': 'bool',
        'sort_index': 'int',
        'uuid_column_output_item_type': 'str'
    }

    attribute_map = {
        'column_id': 'columnId',
        'column_name': 'columnName',
        'column_rules': 'columnRules',
        'column_type': 'columnType',
        'column_uom': 'columnUom',
        'description': 'description',
        'display_property': 'displayProperty',
        'is_generated': 'isGenerated',
        'is_hidden': 'isHidden',
        'is_indexed': 'isIndexed',
        'sort_ascending': 'sortAscending',
        'sort_index': 'sortIndex',
        'uuid_column_output_item_type': 'uuidColumnOutputItemType'
    }

    def __init__(self, column_id=None, column_name=None, column_rules=None, column_type=None, column_uom=None, description=None, display_property=None, is_generated=None, is_hidden=None, is_indexed=None, sort_ascending=None, sort_index=None, uuid_column_output_item_type=None):
        """
        ColumnDefinitionBulkEditInputV1 - a model defined in Swagger
        """

        self._column_id = None
        self._column_name = None
        self._column_rules = None
        self._column_type = None
        self._column_uom = None
        self._description = None
        self._display_property = None
        self._is_generated = None
        self._is_hidden = None
        self._is_indexed = None
        self._sort_ascending = None
        self._sort_index = None
        self._uuid_column_output_item_type = None

        if column_id is not None:
          self.column_id = column_id
        if column_name is not None:
          self.column_name = column_name
        if column_rules is not None:
          self.column_rules = column_rules
        if column_type is not None:
          self.column_type = column_type
        if column_uom is not None:
          self.column_uom = column_uom
        if description is not None:
          self.description = description
        if display_property is not None:
          self.display_property = display_property
        if is_generated is not None:
          self.is_generated = is_generated
        if is_hidden is not None:
          self.is_hidden = is_hidden
        if is_indexed is not None:
          self.is_indexed = is_indexed
        if sort_ascending is not None:
          self.sort_ascending = sort_ascending
        if sort_index is not None:
          self.sort_index = sort_index
        if uuid_column_output_item_type is not None:
          self.uuid_column_output_item_type = uuid_column_output_item_type

    @property
    def column_id(self):
        """
        Gets the column_id of this ColumnDefinitionBulkEditInputV1.
        The optional column id to specify for columns being updated. This must be provided for a column that is being updated. If left blank, a new column will be created.

        :return: The column_id of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._column_id

    @column_id.setter
    def column_id(self, column_id):
        """
        Sets the column_id of this ColumnDefinitionBulkEditInputV1.
        The optional column id to specify for columns being updated. This must be provided for a column that is being updated. If left blank, a new column will be created.

        :param column_id: The column_id of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """

        self._column_id = column_id

    @property
    def column_name(self):
        """
        Gets the column_name of this ColumnDefinitionBulkEditInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for this table

        :return: The column_name of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this ColumnDefinitionBulkEditInputV1.
        Name of the column. This will be used as the header for this column. It must be unique for this table

        :param column_name: The column_name of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """
        if column_name is None:
            raise ValueError("Invalid value for `column_name`, must not be `None`")

        self._column_name = column_name

    @property
    def column_rules(self):
        """
        Gets the column_rules of this ColumnDefinitionBulkEditInputV1.
        The list of rules that determine the resulting value of a column. At least one rule is required

        :return: The column_rules of this ColumnDefinitionBulkEditInputV1.
        :rtype: list[ColumnRuleInputV1]
        """
        return self._column_rules

    @column_rules.setter
    def column_rules(self, column_rules):
        """
        Sets the column_rules of this ColumnDefinitionBulkEditInputV1.
        The list of rules that determine the resulting value of a column. At least one rule is required

        :param column_rules: The column_rules of this ColumnDefinitionBulkEditInputV1.
        :type: list[ColumnRuleInputV1]
        """
        if column_rules is None:
            raise ValueError("Invalid value for `column_rules`, must not be `None`")

        self._column_rules = column_rules

    @property
    def column_type(self):
        """
        Gets the column_type of this ColumnDefinitionBulkEditInputV1.
        The type for the column

        :return: The column_type of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ColumnDefinitionBulkEditInputV1.
        The type for the column

        :param column_type: The column_type of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """
        if column_type is None:
            raise ValueError("Invalid value for `column_type`, must not be `None`")

        self._column_type = column_type

    @property
    def column_uom(self):
        """
        Gets the column_uom of this ColumnDefinitionBulkEditInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :return: The column_uom of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._column_uom

    @column_uom.setter
    def column_uom(self, column_uom):
        """
        Sets the column_uom of this ColumnDefinitionBulkEditInputV1.
        The unit of measure for this column. This is only applicable to columns whose type                      is NUMERIC. If provided, this will enforce that data in this column must be in this unit. For                      example, if the user specifies Fahrenheit and the value comes in as Meters, the value will not be                      inserted. If not provided, values with different units will be allowed to be stored and an extra                       column will be added to the generated table for the UOM

        :param column_uom: The column_uom of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """

        self._column_uom = column_uom

    @property
    def description(self):
        """
        Gets the description of this ColumnDefinitionBulkEditInputV1.
        The optional description for this column.

        :return: The description of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnDefinitionBulkEditInputV1.
        The optional description for this column.

        :param description: The description of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """

        self._description = description

    @property
    def display_property(self):
        """
        Gets the display_property of this ColumnDefinitionBulkEditInputV1.
        The optional display property for this column, defaults to Name if type UUID, otherwise defaults to null.

        :return: The display_property of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._display_property

    @display_property.setter
    def display_property(self, display_property):
        """
        Sets the display_property of this ColumnDefinitionBulkEditInputV1.
        The optional display property for this column, defaults to Name if type UUID, otherwise defaults to null.

        :param display_property: The display_property of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """

        self._display_property = display_property

    @property
    def is_generated(self):
        """
        Gets the is_generated of this ColumnDefinitionBulkEditInputV1.

        :return: The is_generated of this ColumnDefinitionBulkEditInputV1.
        :rtype: bool
        """
        return self._is_generated

    @is_generated.setter
    def is_generated(self, is_generated):
        """
        Sets the is_generated of this ColumnDefinitionBulkEditInputV1.

        :param is_generated: The is_generated of this ColumnDefinitionBulkEditInputV1.
        :type: bool
        """

        self._is_generated = is_generated

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this ColumnDefinitionBulkEditInputV1.

        :return: The is_hidden of this ColumnDefinitionBulkEditInputV1.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this ColumnDefinitionBulkEditInputV1.

        :param is_hidden: The is_hidden of this ColumnDefinitionBulkEditInputV1.
        :type: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_indexed(self):
        """
        Gets the is_indexed of this ColumnDefinitionBulkEditInputV1.

        :return: The is_indexed of this ColumnDefinitionBulkEditInputV1.
        :rtype: bool
        """
        return self._is_indexed

    @is_indexed.setter
    def is_indexed(self, is_indexed):
        """
        Sets the is_indexed of this ColumnDefinitionBulkEditInputV1.

        :param is_indexed: The is_indexed of this ColumnDefinitionBulkEditInputV1.
        :type: bool
        """

        self._is_indexed = is_indexed

    @property
    def sort_ascending(self):
        """
        Gets the sort_ascending of this ColumnDefinitionBulkEditInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :return: The sort_ascending of this ColumnDefinitionBulkEditInputV1.
        :rtype: bool
        """
        return self._sort_ascending

    @sort_ascending.setter
    def sort_ascending(self, sort_ascending):
        """
        Sets the sort_ascending of this ColumnDefinitionBulkEditInputV1.
        Whether to sort ascending if sortIndex is provided, defaults to false

        :param sort_ascending: The sort_ascending of this ColumnDefinitionBulkEditInputV1.
        :type: bool
        """

        self._sort_ascending = sort_ascending

    @property
    def sort_index(self):
        """
        Gets the sort_index of this ColumnDefinitionBulkEditInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :return: The sort_index of this ColumnDefinitionBulkEditInputV1.
        :rtype: int
        """
        return self._sort_index

    @sort_index.setter
    def sort_index(self, sort_index):
        """
        Sets the sort_index of this ColumnDefinitionBulkEditInputV1.
        The sort index for this column. If not provided, the column is not sorted.

        :param sort_index: The sort_index of this ColumnDefinitionBulkEditInputV1.
        :type: int
        """

        self._sort_index = sort_index

    @property
    def uuid_column_output_item_type(self):
        """
        Gets the uuid_column_output_item_type of this ColumnDefinitionBulkEditInputV1.
        The output item type for a UUID column. This value will be used to validate against any items that are returned from rules that return items. If the item's type doesn't match the expected output type, the rule will fail. If not provided, the rule will not validate the item type and any output item type will be allowed

        :return: The uuid_column_output_item_type of this ColumnDefinitionBulkEditInputV1.
        :rtype: str
        """
        return self._uuid_column_output_item_type

    @uuid_column_output_item_type.setter
    def uuid_column_output_item_type(self, uuid_column_output_item_type):
        """
        Sets the uuid_column_output_item_type of this ColumnDefinitionBulkEditInputV1.
        The output item type for a UUID column. This value will be used to validate against any items that are returned from rules that return items. If the item's type doesn't match the expected output type, the rule will fail. If not provided, the rule will not validate the item type and any output item type will be allowed

        :param uuid_column_output_item_type: The uuid_column_output_item_type of this ColumnDefinitionBulkEditInputV1.
        :type: str
        """

        self._uuid_column_output_item_type = uuid_column_output_item_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnDefinitionBulkEditInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ProjectInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _configuration: Optional[List[ScalarPropertyV1]]
    _description: Optional[str]
    _folder_id: Optional[str]
    _name: str
    _owner_id: Optional[str]
    _project_type: Optional[str]
    _resource_size: Optional[str]
    _startup_environment: Optional[str]


    def __init__(
        self,
        configuration: Optional[List[ScalarPropertyV1]] = None,
        description: Optional[str] = None,
        folder_id: Optional[str] = None,
        name: Optional[str] = None,
        owner_id: Optional[str] = None,
        project_type: Optional[str] = None,
        resource_size: Optional[str] = None,
        startup_environment: Optional[str] = None,
    ) -> None: ...

    @property
    def configuration(self) -> Optional[List[ScalarPropertyV1]]: ...

    @configuration.setter
    def configuration(self, configuration: Optional[List[ScalarPropertyV1]]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def folder_id(self) -> Optional[str]: ...

    @folder_id.setter
    def folder_id(self, folder_id: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def owner_id(self) -> Optional[str]: ...

    @owner_id.setter
    def owner_id(self, owner_id: Optional[str]) -> None: ...

    @property
    def project_type(self) -> Optional[str]: ...

    @project_type.setter
    def project_type(self, project_type: Optional[str]) -> None: ...

    @property
    def resource_size(self) -> Optional[str]: ...

    @resource_size.setter
    def resource_size(self, resource_size: Optional[str]) -> None: ...

    @property
    def startup_environment(self) -> Optional[str]: ...

    @startup_environment.setter
    def startup_environment(self, startup_environment: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ContentApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_asset_selection(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_content(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def archive_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_date_range(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def clear_image_cache(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def clear_image_cache_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def create_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def create_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def create_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def get_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def get_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content_items(
        self,
        **kwargs: Any,
    ) -> GetContentItemsOutputV1: ...

    def get_content_items_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_content_items_for_date_range(
        self,
        **kwargs: Any,
    ) -> GetContentItemsOutputV1: ...

    def get_content_items_for_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_contents_with_all_metadata(
        self,
        **kwargs: Any,
    ) -> ContentWithMetadataListOutputV1: ...

    def get_contents_with_all_metadata_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def get_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_date_ranges(
        self,
        **kwargs: Any,
    ) -> GetDateRangesOutputV1: ...

    def get_date_ranges_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_image(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def get_image_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_notifiable_reports(
        self,
        **kwargs: Any,
    ) -> NotifiableReportOutputListV1: ...

    def get_notifiable_reports_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_react_blob(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_react_blob_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_schedulable_statistics(
        self,
        **kwargs: Any,
    ) -> SchedulableAdminListOutputV1: ...

    def get_schedulable_statistics_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_schedulable_summary(
        self,
        **kwargs: Any,
    ) -> SchedulableSummaryWeekOutputV1: ...

    def get_schedulable_summary_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def preview_content(
        self,
        **kwargs: Any,
    ) -> bytes: ...

    def preview_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def redirect_to_source_worksheet(
        self,
        **kwargs: Any,
    ) -> str: ...

    def redirect_to_source_worksheet_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_asset_selection(
        self,
        **kwargs: Any,
    ) -> AssetSelectionOutputV1: ...

    def update_asset_selection_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_content(
        self,
        **kwargs: Any,
    ) -> ContentOutputV1: ...

    def update_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_date_range(
        self,
        **kwargs: Any,
    ) -> DateRangeOutputV1: ...

    def update_date_range_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_last_viewed_time(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def update_last_viewed_time_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.119.1-v202603241138-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class SignalsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def add_samples(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def add_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def add_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def add_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_signal(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def archive_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def create_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_samples(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sample(
        self,
        **kwargs: Any,
    ) -> GetSampleOutputV1: ...

    def get_sample_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_sample_by_data_id(
        self,
        **kwargs: Any,
    ) -> GetSampleOutputV1: ...

    def get_sample_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_samples(
        self,
        **kwargs: Any,
    ) -> GetSamplesOutputV1: ...

    def get_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> GetSamplesOutputV1: ...

    def get_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def get_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def get_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_signals(
        self,
        **kwargs: Any,
    ) -> GetSignalsOutputV1: ...

    def get_signals_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_samples(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def put_samples_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_samples_by_data_id(
        self,
        **kwargs: Any,
    ) -> SamplesOutputV1: ...

    def put_samples_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signal(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def put_signal_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signal_by_data_id(
        self,
        **kwargs: Any,
    ) -> SignalOutputV1: ...

    def put_signal_by_data_id_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def put_signals(
        self,
        **kwargs: Any,
    ) -> ItemBatchOutputV1: ...

    def put_signals_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
